/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { StyleProp, ViewProps, ViewStyle } from 'react-native';
import { StyledComponentProps } from '../../theme';
import { BottomNavigationTabElement } from './bottomNavigationTab.component';
declare type ChildrenProp = BottomNavigationTabElement | BottomNavigationTabElement[];
interface ComponentProps {
    children: ChildrenProp;
    selectedIndex?: number;
    indicatorStyle?: StyleProp<ViewStyle>;
    onSelect?: (index: number) => void;
}
export declare type BottomNavigationProps = StyledComponentProps & ViewProps & ComponentProps;
export declare type BottomNavigationElement = React.ReactElement<BottomNavigationProps>;
/**
 * `BottomNavigation` component is designed to be a Bottom Tab Bar.
 * Can be used for navigation.
 *
 * @extends React.Component
 *
 * @property {number} selectedIndex - Determines index of the selected tab.
 *
 * @property {string} appearance - Determines the appearance of the component.
 * Can be `default` | `noIndicator`.
 *
 * @property {React.ReactElement<TabProps> | React.ReactElement<TabProps>[]} children -
 * Determines tabs of the Bottom Navigation.
 *
 * @property {StyleProp<ViewStyle>} indicatorStyle - Determines styles of the indicator.
 *
 * @property {(index: number) => void} onSelect - Triggered on select value.
 *
 * @property ViewProps
 *
 * @property StyledComponentProps
 *
 * @overview-example Simple Usage
 *
 * ```
 * import React from 'react';
 * import { BottomNavigation, BottomNavigationTab } from '../..';
 *
 * export class BottomNavigationShowcase extends React.Component {
 *
 *   state = {
 *     selectedIndex: 0,
 *   };
 *
 *   onTabSelect = (selectedIndex) => {
 *     this.setState({ selectedIndex });
 *   };
 *
 *   render() {
 *     return (
 *       <BottomNavigation
 *         selectedIndex={this.state.selectedIndex}
 *         onSelect={this.onTabSelect}>
 *          <BottomNavigationTab title='Dashboard' />
 *          <BottomNavigationTab title='Settings' />
 *       </BottomNavigation>
 *     );
 *   }
 * }
 * ```
 *
 * @overview-example With React Navigation
 *
 * ```
 * import React from 'react';
 * import { BottomNavigation, BottomNavigationTab } from '../..';
 * import { createBottomTabNavigator } from 'react-navigation-tabs';
 * import { Dashboard, Settings } from './path-to/screen-components'; // <-- Import screen components
 *
 * export const BottomNavigationShowcase = (props) => {
 *
 *  const onTabSelect = (selectedIndex) => {
 *    const { [index]: selectedRoute } = props.navigation.state.routes;
 *    props.navigation.navigate(selectedRoute.routeName);
 *  };
 *
 *  return (
 *    <BottomNavigation
 *      selectedIndex={props.navigation.state.index}
 *      onSelect={onTabSelect}>
 *      <BottomNavigationTab title='Dashboard' />
 *      <BottomNavigationTab title='Settings' />
 *    </BottomNavigation>
 *   );
 * }
 *
 * export const BottomTabNavigator = createBottomTabNavigator({
 *   Dashboard: Dashboard,
 *   Settings: Settings,
 * }, {
 *   initialRouteName: 'Dashboard',
 *   tabBarComponent: BottomNavigationShowcase,
 * });
 * ```
 *
 * @example Without Indicator
 *
 * ```
 * import React from 'react';
 * import { BottomNavigation, BottomNavigationTab } from '../..';
 *
 * export class BottomNavigationShowcase extends React.Component {
 *
 *   state = {
 *     selectedIndex: 0,
 *   };
 *
 *   onTabSelect = (selectedIndex) => {
 *     this.setState({ selectedIndex });
 *   };
 *
 *   render()  {
 *     return (
 *       <BottomNavigation
 *          appearance='noIndicator'
 *          selectedIndex={this.state.selectedIndex}
 *          onSelect={this.onTabSelect}>
 *          <BottomNavigationTab title='Dashboard' />
 *          <BottomNavigationTab title='Settings' />
 *       </BottomNavigation>
 *     );
 *   }
 * }
 * ```
 *
 * @example Inline Styling
 *
 * ```
 * import React from 'react';
 * import { StyleSheet } from 'react-native';
 * import { BottomNavigation, BottomNavigationTab } from '../..';
 *
 * export const BottomNavigationShowcase = (props) => (
 *   <BottomNavigation
 *      style={styles.bottomNavigation}
 *      indicatorStyle={styles.indicator}>
 *      <BottomNavigationTab title='Dashboard' />
 *      <BottomNavigationTab title='Settings' />
 *   </BottomNavigation>
 * );
 *
 * const styles = StyleSheet.create({
 *   bottomNavigation: { backgroundColor: 'white' },
 *   indicator: { backgroundColor: 'black' },
 * });
 * ```
 */
export declare class BottomNavigationComponent extends React.Component<BottomNavigationProps> {
    static styledComponentName: string;
    static defaultProps: Partial<BottomNavigationProps>;
    private onTabSelect;
    private getComponentStyle;
    private renderIndicatorElement;
    private renderTabElement;
    private renderTabElements;
    private renderComponentChildren;
    render(): React.ReactNode;
}
export declare const BottomNavigation: React.ComponentClass<BottomNavigationProps, any>;
export {};
