/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { ImageProps, ImageStyle, StyleProp, TextStyle, TouchableOpacityProps } from 'react-native';
import { StyledComponentProps } from '../../theme';
declare type IconElement = React.ReactElement<ImageProps>;
declare type IconProp = (style: ImageStyle) => IconElement;
interface ComponentProps {
    title?: string;
    titleStyle?: StyleProp<TextStyle>;
    icon?: IconProp;
    selected?: boolean;
    onSelect?: (selected: boolean) => void;
}
export declare type BottomNavigationTabProps = StyledComponentProps & TouchableOpacityProps & ComponentProps;
export declare type BottomNavigationTabElement = React.ReactElement<BottomNavigationTabProps>;
/**
 * `BottomNavigationTab` component is a part of the `BottomNavigation` component.
 * `BottomNavigation` tabs should be wrapped in BottomNavigation to provide usable component.
 * See usage examples at `BottomNavigation` component documentation.
 *
 * @extends React.Component
 *
 * @property {boolean} selected - Determines whether component is selected.
 *
 * @property {string} title - Determines the title of the tab.
 *
 * @property {StyleProp<TextStyle>} titleStyle - Customizes title style.
 *
 * @property {(style: StyleType) => React.ReactElement<ImageProps>} icon - Determines the icon of the tab.
 *
 * @property {(selected: boolean) => void} onSelect - Triggered on select value.
 *
 * @property TouchableOpacityProps
 *
 * @property StyledComponentProps
 *
 * @overview-example Simple Usage
 *
 * ```
 * import React from 'react';
 * import { BottomNavigationTab } from '../..';
 *
 * export const BottomNavigationTabShowcase = (props) => (
 *   <BottomNavigationTab title='Dashboard' />
 * );
 * ```
 *
 * @overview-example With Icon
 *
 * ```
 * // IMPORTANT: To use Icon component make sure to follow this guide:
 * // https://akveo.github.io/react-native-ui-kitten/docs/guides/eva-icons
 *
 * import React from 'react';
 * import { BottomNavigationTab, Icon } from '../..';
 *
 * const DashboardIcon = (style) => (
 *   <Icon {...style} name='layout' />
 * );
 *
 * export const BottomNavigationTabShowcase = (props) => (
 *   <BottomNavigationTab title='Dashboard' icon={DashboardIcon} />
 * );
 * ```
 *
 * @example Using Asset Icons
 *
 * ```
 * import React from 'react';
 * import { Image } from 'react-native';
 * import { BottomNavigationTab } from '../..';
 *
 * const DashboardIcon = (style) => (
 *   <Image style={style} source={require('path-to-assets/local-image.png')} />
 * );
 *
 * export const BottomNavigationTabShowcase = (props) => (
 *   <BottomNavigationTab title='Dashboard' icon={DashboardIcon} />
 * );
 * ```
 *
 * @example Inline Styling
 *
 * ```
 * import React from 'react';
 * import { StyleSheet } from 'react-native';
 * import { BottomNavigationTab } from '../..';
 *
 * export const BottomNavigationTabShowcase = (props) => (
 *   <BottomNavigationTab
 *     style={styles.tab}
 *     titleStyle={styles.tabTitle}
 *     title='Dashboard'
 *   />
 * );
 *
 * const styles = StyleSheet.create({
 *   tab: { backgroundColor: 'white' },
 *   tabTitle: { color: 'black' },
 * });
 * ```
 */
export declare class BottomNavigationTabComponent extends React.Component<BottomNavigationTabProps> {
    static styledComponentName: string;
    private onPress;
    private getComponentStyle;
    private renderIconElement;
    private renderTitleElement;
    private renderComponentChildren;
    render(): React.ReactNode;
}
export declare const BottomNavigationTab: React.ComponentClass<BottomNavigationTabProps, any>;
export {};
