var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import { Animated, } from 'react-native';
import { getIconAnimation, } from './iconAnimation';
import { IconRegistryService, } from './service/iconRegistry.service';
/**
 * `Icon` component with animation support. Allows to render any ReactElement registered for a specific name.
 * Starting from UI Kitten 4.2, there is `@ui-kitten/eva-icons` module
 * that renders any icon from eva-icons package in `svg` format.
 * It allows easily use icons in any component that has `icon` prop
 *
 * @extends React.Component
 *
 * @method {(callback?: Animated.EndCallback) => void} startAnimation - Toggle animation to start.
 *
 * @method {() => void} stopAnimation - Toggle animation to stop.
 *
 * @property {string} name - Name of registered icon.
 *
 * @property {string} pack - Name of icon pack that is able to provide an icon for specified name.
 *
 * @property {string} animation - Animation name. Available `zoom`, `pulse` and `shake`. Default is `zoom`.
 *
 * @property {AnimationConfig} animationConfig - Determines animation config. Extends `Animated.AnimationConfig`.
 *
 * @overview-example Register Icons
 *
 * ```
 * import React from 'react';
 * import { mapping, light as lightTheme } from '@eva-design/eva';
 * import { ApplicationProvider, IconRegistry, Layout, Text } from '../..';
 * import { EvaIconsPack } from '../../../eva-icons'; // <-- Make sure it is installed. npm i @ui-kitten/eva-icons
 *
 * const ApplicationContent = () => (
 *   <Layout style={{flex: 1, justifyContent: 'center', alignItems: 'center'}}>
 *     <Text>Welcome to UI Kitten</Text>
 *   </Layout>
 * );
 *
 * const App = () => (
 *   <React.Fragment>
 *     <IconRegistry icons={EvaIconsPack}/>
 *     <ApplicationProvider mapping={mapping} theme={lightTheme}>
 *       <ApplicationContent/>
 *     </ApplicationProvider>
 *   </React.Fragment>
 * );
 *
 * export default App;
 * ```
 *
 * @overview-example Simple Usage
 *
 * ```
 * import React from 'react';
 * import { Icon } from '../..';
 *
 * export const StarIcon = (props) => (
 *   <Icon name='star'/>
 * );
 * ```
 *
 * @overview-example Using with UI Kitten components
 *
 * ```
 * import React from 'react';
 * import { Input, Button, Icon } from '../..';
 *
 * const FacebookIcon = (style) => (
 *   <Icon {...style} name='facebook' />
 * );
 *
 * const EyeIcon = (style) => (
 *   <Icon {...style} name='eye' />
 * );
 *
 * export const LoginButton = (props) => (
 *   <Button icon={FacebookIcon}>Login with Facebook</Button>
 * );
 *
 * export const PasswordInput = (props) => (
 *   <Input placeholder='Password' icon={EyeIcon} />
 * );
 * ```
 *
 * @overview-example Using Asset Source
 *
 * ```
 * import React from 'react';
 * import { Image } from 'react-native';
 * import { Button } from '../..';
 *
 * const FacebookIcon = (style) => (
 *   <Image style={style} source={require('path-to-assets/local-image.png')} />
 * );
 *
 * export const LoginButton = (props) => (
 *   <Button icon={FacebookIcon}>Login with Facebook</Button>
 * );
 * ```
 *
 * @overview-example Animation Usage
 *
 * ```
 * import React from 'react';
 * import { Icon } from '../..';
 *
 * const iconRef = React.createRef();
 *
 * export const StarIcon = (props) => (
 *   <Icon ref={iconRef} name='star' animation='shake'/>
 * );
 *
 * iconRef.current.startAnimation();
 * ```
 *
 * @example Infinite Animation
 *
 * ```
 * import React from 'react';
 * import { Icon } from '../..';
 *
 * const iconRef = React.createRef();
 *
 * export const StarIcon = (props) => (
 *   <Icon
 *     ref={iconRef}
 *     name='star'
 *     animation='shake'
 *     animationConfig={{ cycles: -1 }}
 *   />
 * );
 *
 * iconRef.current.startAnimation();
 * ```
 *
 * @example Password Input
 *
 * ```
 * import React from 'react';
 * import { Input, Icon } from '../..';
 *
 * export class PasswordInput extends React.Component {
 *
 *  state = {
 *    passwordVisible: false,
 *  };
 *
 *  onPasswordIconPress = () => {
 *    const passwordVisible = !this.state.passwordVisible;
 *    this.setState({ passwordVisible });
 *  };
 *
 *  renderPasswordIcon = (style) => (
 *    <Icon
 *      name={this.state.passwordVisible ? 'eye' : 'eye-off'}
 *      {...style}
 *    />
 *  );
 *
 *  render() {
 *    return (
 *      <Input
 *        icon={this.renderPasswordIcon}
 *        onIconPress={this.onPasswordIconPress}
 *        secureTextEntry={!this.state.passwordVisible}
 *      />
 *    );
 *  }
 * }
 * ```
 *
 * @example Like Button
 *
 * ```
 * import React from 'react';
 * import { Button, Icon } from '../..';
 *
 * export class LikeButton extends React.Component {
 *
 *  state = {
 *    liked: false,
 *  };
 *
 *  onPress = () => {
 *    const liked = !this.state.liked;
 *    this.setState({ liked });
 *  };
 *
 *  renderHeartIcon = (style) => (
 *    <Icon
 *      name={this.state.liked ? 'heart' : 'heart-outline'}
 *      {...style}
 *    />
 *  );
 *
 *  render() {
 *    return (
 *      <Button
 *        icon={this.renderHeartIcon}
 *        onPress={this.onPress}
 *      />
 *    );
 *  }
 * }
 * ```
 *
 * @example Inline Styling
 *
 * ```
 * // Visit react-native-svg documentation for more details
 * // https://github.com/react-native-community/react-native-svg#common-props
 *
 * import React from 'react';
 * import { Icon } from '../..';
 *
 * export const StarIcon = (props) => (
 *   <Icon name='star' width={32} height={32} fill='#000'/>
 * );
 * ```
 */
export class Icon extends React.Component {
    constructor(props) {
        super(props);
        this.startAnimation = (callback) => {
            this.animation.start(callback);
        };
        this.stopAnimation = () => {
            this.animation.stop();
        };
        this.getComponentStyle = () => {
            return this.animation.toProps();
        };
        this.animation = getIconAnimation(props.animation, props.animationConfig);
    }
    componentWillUnmount() {
        this.animation.release();
    }
    render() {
        const _a = this.props, { name, pack } = _a, restProps = __rest(_a, ["name", "pack"]);
        const registeredIcon = IconRegistryService.getIcon(name, pack);
        return (<Animated.View {...this.getComponentStyle()}>
        {registeredIcon.icon.toReactElement(restProps)}
      </Animated.View>);
    }
}
Icon.defaultProps = {
    animation: 'zoom',
};
//# sourceMappingURL=icon.component.js.map