/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { GestureResponderEvent, ImageProps, StyleProp, TextInputProps, TextStyle } from 'react-native';
import { StyledComponentProps, StyleType } from '../../theme';
declare type IconElement = React.ReactElement<ImageProps>;
declare type IconProp = (style: StyleType) => IconElement;
interface ComponentProps {
    status?: string;
    size?: string;
    disabled?: boolean;
    label?: string;
    caption?: string;
    captionIcon?: IconProp;
    icon?: IconProp;
    textStyle?: StyleProp<TextStyle>;
    labelStyle?: StyleProp<TextStyle>;
    captionTextStyle?: StyleProp<TextStyle>;
    onIconPress?: (event: GestureResponderEvent) => void;
}
export declare type InputProps = StyledComponentProps & TextInputProps & ComponentProps;
export declare type InputElement = React.ReactElement<InputProps>;
/**
 * Styled `Input` component.
 *
 * @extends React.Component
 *
 * @method {() => void} focus - Requests focus for the given input or view. The exact behavior triggered
 * will depend on the platform and type of view.
 *
 * @method {() => void} blur - Removes focus from an input or view. This is the opposite of `focus()`.
 *
 * @method {() => boolean} isFocused - Returns if the input is currently focused.
 *
 * @method {() => void} clear - Removes all text from the input.
 *
 * @property {boolean} disabled - Determines whether component is disabled.
 * Default is `false`.
 *
 * @property {string} status - Determines the status of the component.
 * Can be `primary`, `success`, `info`, `warning` or `danger`.
 *
 * @property {string} size - Determines the size of the component.
 * Can be `large`, `medium` or `small`.
 * Default is `medium`.
 *
 * @property {string} label - Determines label of the component.
 *
 * @property {StyleProp<TextStyle>} labelStyle - Customizes label style.
 *
 * @property {string} caption - Determines caption of the component.
 *
 * @property {StyleProp<TextStyle>} captionStyle - Customizes caption style.
 *
 * @property {string} placeholder - Determines placegolder of the component.
 *
 * @property {StyleProp<TextStyle>} textStyle - Customizes text style.
 *
 * @property {(style: StyleType) => React.ReactElement<ImageProps>} icon - Determines icon of the component.
 *
 * @property {(style: StyleType) => React.ReactElement<ImageProps>} captionIcon - Determines caption icon.
 *
 * @property TextInputProps
 *
 * @property StyledComponentProps
 *
 * @overview-example Simple Usage
 *
 * ```
 * import React from 'react';
 * import { Input } from '../..';
 *
 * export class InputShowcase extends React.Component {
 *
 *   state = {
 *     inputValue: '',
 *   };
 *
 *   onInputValueChange = (inputValue) => {
 *     this.setState({ inputValue });
 *   };
 *
 *   render() {
 *     return (
 *       <Input
 *         value={this.state.inputValue}
 *         onChangeText={this.onInputValueChange}
 *       />
 *     );
 *   }
 * }
 * ```
 *
 * @overview-example With Icon
 *
 * ```
 * // IMPORTANT: To use Icon component make sure to follow this guide:
 * // https://akveo.github.io/react-native-ui-kitten/docs/guides/eva-icons
 *
 * import React from 'react';
 * import { Input, Icon } from '../..';
 *
 * export class SecureInput extends React.Component {
 *
 *   state = {
 *     inputValue: '',
 *     secureTextEntry: true,
 *   };
 *
 *   onInputValueChange = (inputValue) => {
 *     this.setState({ inputValue });
 *   };
 *
 *   onIconPress = () => {
 *     const secureTextEntry = !this.state.secureTextEntry;
 *     this.setState({ secureTextEntry });
 *   };
 *
 *   renderIcon = (style) => (
 *     const iconName = this.state.secureTextEntry ? 'eye' : 'eye-off';
 *     return (
 *       <Icon {...style} name={iconName} />
 *     );
 *   );
 *
 *   render() {
 *     return (
 *       <Input
 *         value={this.state.inputValue}
 *         icon={this.renderIcon}
 *         secureTextEntry={this.state.secureTextEntry}
 *         onIconPress={this.onIconPress}
 *         onChangeText={this.onInputValueChange}
 *       />
 *     );
 *   }
 * }
 * ```
 *
 * @overview-example With Label
 *
 * ```
 * import React from 'react';
 * import { Input } from '../..';
 *
 * export class EmailInput extends React.Component {
 *
 *   state = {
 *     inputValue: '',
 *   };
 *
 *   onInputValueChange = (inputValue) => {
 *     this.setState({ inputValue });
 *   };
 *
 *   render() {
 *     return (
 *       <Input
 *         label='EMAIL'
 *         value={this.state.inputValue}
 *         onChangeText={this.onInputValueChange}
 *       />
 *     );
 *   }
 * }
 * ```
 * @overview-example With Caption
 *
 * ```
 * import React from 'react';
 * import { Input } from '../..';
 *
 * export class PasswordInput extends React.Component {
 *
 *   state = {
 *     inputValue: '',
 *   };
 *
 *   onInputValueChange = (inputValue) => {
 *     this.setState({ inputValue });
 *   };
 *
 *   isValidInputValue = () => {
 *     return this.state.inputValue.length >= 6;
 *   };
 *
 *   render() {
 *     const isValidInputValue = this.isValidInputValue();
 *     return (
 *       <Input
 *         status={isValidInputValue ? 'success' : 'danger'}
 *         caption={isValidInputValue ? '' : 'Invalid password'}
 *         value={this.state.inputValue}
 *         onChangeText={this.onInputValueChange}
 *       />
 *     );
 *   }
 * }
 * ```
 *
 * @overview-example Eva Styling
 *
 * ```
 * import React from 'react';
 * import { Input } from '../..';
 *
 * export class InputShowcase extends React.Component {
 *
 *   state = {
 *     inputValue: '',
 *   };
 *
 *   onInputValueChange = (inputValue) => {
 *     this.setState({ inputValue });
 *   };
 *
 *   render() {
 *     return (
 *       <Input
 *         size='large'
 *         status='danger'
 *         value={this.state.inputValue}
 *         onChangeText={this.onInputValueChange}
 *       />
 *     );
 *   }
 * }
 * ```
 *
 * @example Using Asset Icons
 *
 * ```
 * import React from 'react';
 * import { Image } from 'react-native';
 * import { Input } from '../..';
 *
 * const StarIcon = (style) => (
 *   <Image style={style} source={require('path-to-assets/local-image.png')} />
 * );
 *
 * export const StarInput = (props) => (
 *   <Input icon={StarIcon} />
 * );
 * ```
 *
 * @example Inline Styling
 *
 * ```
 * import React from 'react';
 * import { StyleSheet } from 'react-native';
 * import { Input } from '../..';
 *
 * export class InputShowcase extends React.Component {
 *
 *   state = {
 *     inputValue: '',
 *   };
 *
 *   onInputValueChange = (inputValue) => {
 *     this.setState({ inputValue });
 *   };
 *
 *   render() {
 *     return (
 *       <Input
 *         value={this.state.inputValue}
 *         style={styles.input}
 *         textStyle={styles.inputText}
 *         labelStyle={styles.inputLabel}
 *         captionStyle={styles.inputCaption}
 *         onChangeText={this.onInputValueChange}
 *       />
 *     );
 *   }
 * }
 *
 * const styles = StyleSheet.create({
 *   input: { borderRadius: 8 },
 *   inputText: { color: 'black' },
 *   inputLabel: { color: 'gray' },
 *   inputCaption: { color: 'gray' },
 * });
 * ```
 */
export declare class InputComponent extends React.Component<InputProps> {
    static styledComponentName: string;
    private textInputRef;
    focus: () => void;
    blur: () => void;
    isFocused: () => boolean;
    clear: () => void;
    private onFocus;
    private onBlur;
    private onIconPress;
    private getComponentStyle;
    private renderIconTouchableElement;
    private renderIconElement;
    private renderLabelElement;
    private renderCaptionElement;
    private renderCaptionIconElement;
    private renderComponentChildren;
    render(): React.ReactElement<TextInputProps>;
}
export declare const Input: React.ComponentClass<InputProps, any>;
export {};
