/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { StyleProp, TextStyle, ViewProps } from 'react-native';
import { StyledComponentProps } from '../../theme';
import { TopNavigationActionElement } from './topNavigationAction.component';
declare type ActionElementProp = TopNavigationActionElement | TopNavigationActionElement[];
declare type AlignmentProp = 'start' | 'center';
interface ComponentProps {
    title?: string;
    titleStyle?: StyleProp<TextStyle>;
    subtitle?: string;
    subtitleStyle?: StyleProp<TextStyle>;
    alignment?: AlignmentProp;
    leftControl?: TopNavigationActionElement;
    rightControls?: ActionElementProp;
}
export declare type TopNavigationProps = StyledComponentProps & ViewProps & ComponentProps;
export declare type TopNavigationElement = React.ReactElement<TopNavigationProps>;
/**
 * `TopNavigation` component is designed to be a Navigation Bar.
 * Can be used for navigation.
 *
 * @extends React.Component
 *
 * @property {string} title - Determines the title of the component.
 *
 * @property {string} subtitle - Determines the subtitle of the component.
 *
 * @property {string} alignment - Determines the alignment of the component.
 * Can be `center` or `start`.
 *
 * @property {React.ReactElement<TopNavigationActionProps>} leftControl - Determines the left control
 * of the component.
 *
 * @property {React.ReactElement<TopNavigationActionProps>[]} rightControls - Determines the right controls
 * of the component.
 *
 * @property {StyleProp<TextStyle>} titleStyle - Customizes text style of title.
 *
 * @property {StyleProp<TextStyle>} subtitleStyle - Customizes text style of subtitle.
 *
 * @property ViewProps
 *
 * @property StyledComponentProps
 *
 * @overview-example Simple Usage
 *
 * ```
 * import React from 'react';
 * import { TopNavigation } from '../..';
 *
 * export const AwesomeAppHeader = (props) => (
 *   <TopNavigation title='Awesome App' />
 * );
 * ```
 *
 * @overview-example Actions
 *
 * ```
 * // IMPORTANT: To use Icon component make sure to follow this guide:
 * // https://akveo.github.io/react-native-ui-kitten/docs/guides/eva-icons
 *
 * import React from 'react';
 * import { TopNavigation, TopNavigationAction, Icon } from '../..';
 *
 * const BackIcon = (style) => (
 *   <Icon {...style} name='arrow-back' />
 * );
 *
 * const EditIcon = (style) => (
 *   <Icon {...style} name='edit' />
 * );
 *
 * const MenuIcon = (style) => (
 *   <Icon {...style} name='more-vertical' />
 * );
 *
 * const BackAction = (props) => (
 *   <TopNavigationAction {...props} icon={BackIcon} />
 * );
 *
 * const EditAction = (props) => (
 *   <TopNavigationAction {...props} icon={EditIcon} />
 * );
 *
 * const MenuAction = (props) => (
 *   <TopNavigationAction {...props} icon={MenuIcon} />
 * );
 *
 * export const AwesomeAppHeader = (props) => {
 *
 *   const onBackPress = () => {};
 *
 *   const renderLeftControl = () => (
 *     <BackAction onPress={onBackPress} />
 *   );
 *
 *   const renderRightControls = () => [
 *     <EditAction />,
 *     <MenuAction />,
 *   ];
 *
 *   return (
 *     <TopNavigation
 *       title='Awesome App'
 *       leftControl={renderLeftControl()}
 *       rightControls={renderRightControls()}
 *     />
 *   );
 * };
 * ```
 *
 * @example With Menu
 *
 * ```
 * import React from 'react';
 * import { OverflowMenu, TopNavigation, TopNavigationAction, Icon } from '../..';
 *
 * const BackIcon = (style) => (
 *   <Icon {...style} name='arrow-back'/>
 * );
 *
 * const MenuIcon = (style) => (
 *   <Icon {...style} name='more-vertical'/>
 * );
 *
 * export class TopNavigationWithMenu extends React.Component {
 *
 *   state = {
 *     menuVisible: false,
 *   };
 *
 *   toggleMenu = () => {
 *     const menuVisible = !this.state.menuVisible;
 *     this.setState({ menuVisible });
 *   };
 *
 *   onMenuItemSelect = (index) => {
 *     this.toggleMenu();
 *     this.props.onMenuItemSelect && this.props.onMenuItemSelect(index);
 *   };
 *
 *   renderMenuAction = () => (
 *     <OverflowMenu
 *       visible={this.state.menuVisible}
 *       data={this.props.menu}
 *       onSelect={this.onMenuItemSelect}
 *       onBackdropPress={this.toggleMenu}>
 *       <TopNavigationAction icon={MenuIcon} onPress={this.toggleMenu} />
 *     </OverflowMenu>
 *   );
 *
 *   renderBackAction = () => (
 *     <TopNavigationAction icon={BackIcon} onPress={this.props.onBackPress} />
 *   );
 *
 *   render() {
 *     const { menu, onBackPress, ...restProps } = this.props;
 *     return (
 *       <TopNavigation
 *         leftControl={onBackPress && this.renderBackAction()}
 *         rightControls={menu && this.renderMenuAction()}
 *         {...restProps}
 *       />
 *     );
 *   }
 * }
 *
 * // USAGE:
 *
 * const InfoIcon = (style) => (
 *   <Icon {...style} name='info'/>
 * );
 *
 * const LogoutIcon = (style) => (
 *   <Icon {...style} name='log-out'/>
 * );
 *
 * const navigationMenu = [
 *   { title: 'About', icon: InfoIcon },
 *   { title: 'Logout', icon: LogoutIcon },
 * ];
 *
 * export const HomeScreen = () => {
 *
 *   const onMenuItemSelect = () => {};
 *
 *   const onBackPress = () => {};
 *
 *   return (
 *     <TopNavigationWithMenu
 *       menu={navigationMenu}
 *       onMenuItemSelect={onMenuItemSelect}
 *       onBackPress={onBackPress}
 *     />
 *   );
 * };
 * ```
 *
 * @example Centered Title
 *
 * ```
 * import React from 'react';
 * import { TopNavigation } from '../..';
 *
 * export const AwesomeAppHeader = (props) => (
 *   <TopNavigation alignment='center' title='Awesome App' />
 * );
 * ```
 *
 * @example Inline Styling
 *
 * ```
 * import React from 'react';
 * import { StyleSheet } from 'react-native';
 * import { TopNavigation } from '../..';
 *
 * export const AwesomeAppHeader = (props) => (
 *   <TopNavigation
 *     style={styles.header}
 *     title='Awesome App'
 *     subtitle='Subtitle'
 *     titleStyle={styles.headerTitle}
 *     subtitleStyle={styles.headerSubtitle}
 *   />
 * );
 *
 * const styles = StyleSheet.create({
 *   header: { backgroundColor: 'black' },
 *   headerTitle: { color: 'white' },
 *   headerSubtitle: { color: 'gray' },
 * });
 * ```
 */
export declare class TopNavigationComponent extends React.Component<TopNavigationProps> {
    static styledComponentName: string;
    private getAlignmentDependentStyles;
    private getComponentStyle;
    private renderTextElement;
    private renderActionElements;
    private renderComponentChildren;
    render(): React.ReactNode;
}
export declare const TopNavigation: React.ComponentClass<TopNavigationProps, any>;
export {};
